==> kdesvn_1.2.4.orig.tar.gz: kdesvn-1.2.4/src/ksvnwidgets/models/commitmodelfwd.h <==
/***************************************************************************
 *   Copyright (C) 2005-2008 by Rajko Albrecht                             *
 *   ral@alwins-world.de                                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#ifndef _COMMITMODELFWD_H
#define _COMMITMODELFWD_H

#include "src/svnqt/shared_pointer.hpp"

#include <QList>

class CommitActionEntry;
class CommitModelNode;

typedef svn::SharedPointer<CommitActionEntry> CommitActionEntryPtr;
typedef svn::SharedPointer<CommitModelNode> CommitModelNodePtr;

typedef QList<CommitActionEntry> CommitActionEntries;
typedef QList<CommitModelNodePtr> CommitModelNodeList;

#endif

==> kdesvn_1.4.1.orig.tar.gz: kdesvn-1.4.1/src/ksvnwidgets/models/commitmodelfwd.h <==
/***************************************************************************
 *   Copyright (C) 2005-2008 by Rajko Albrecht                             *
 *   ral@alwins-world.de                                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#ifndef COMMITMODELFWD_H
#define COMMITMODELFWD_H

#include "src/svnqt/shared_pointer.hpp"

#include <QList>

class CommitActionEntry;
class CommitModelNode;

typedef svn::SharedPointer<CommitActionEntry> CommitActionEntryPtr;
typedef svn::SharedPointer<CommitModelNode> CommitModelNodePtr;

typedef QList<CommitActionEntry> CommitActionEntries;
typedef QList<CommitModelNodePtr> CommitModelNodeList;

#endif
